==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/python/ProjenrcOptions.java <==
package io.github.cdklabs.projen.python;

/**
 * (experimental) Options for `Projenrc`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.901Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.ProjenrcOptions")
@software.amazon.jsii.Jsii.Proxy(ProjenrcOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ProjenrcOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The name of the projenrc file.
     * <p>
     * Default: ".projenrc.py"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getFilename() {
        return null;
    }

    /**
     * (experimental) The projen version to use.
     * <p>
     * Default: - current version
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getProjenVersion() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<ProjenrcOptions> {
        java.lang.String filename;
        java.lang.String projenVersion;

        /**
         * Sets the value of {@link ProjenrcOptions#getFilename}
         * @param filename The name of the projenrc file.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder filename(java.lang.String filename) {
            this.filename = filename;
            return this;
        }

        /**
         * Sets the value of {@link ProjenrcOptions#getProjenVersion}
         * @param projenVersion The projen version to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder projenVersion(java.lang.String projenVersion) {
            this.projenVersion = projenVersion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ProjenrcOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public ProjenrcOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ProjenrcOptions {
        private final java.lang.String filename;
        private final java.lang.String projenVersion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.filename = software.amazon.jsii.Kernel.get(this, "filename", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.projenVersion = software.amazon.jsii.Kernel.get(this, "projenVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.filename = builder.filename;
            this.projenVersion = builder.projenVersion;
        }

        @Override
        public final java.lang.String getFilename() {
            return this.filename;
        }

        @Override
        public final java.lang.String getProjenVersion() {
            return this.projenVersion;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getFilename() != null) {
                data.set("filename", om.valueToTree(this.getFilename()));
            }
            if (this.getProjenVersion() != null) {
                data.set("projenVersion", om.valueToTree(this.getProjenVersion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.python.ProjenrcOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ProjenrcOptions.Jsii$Proxy that = (ProjenrcOptions.Jsii$Proxy) o;

            if (this.filename != null ? !this.filename.equals(that.filename) : that.filename != null) return false;
            return this.projenVersion != null ? this.projenVersion.equals(that.projenVersion) : that.projenVersion == null;
        }

        @Override
        public final int hashCode() {
            int result = this.filename != null ? this.filename.hashCode() : 0;
            result = 31 * result + (this.projenVersion != null ? this.projenVersion.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/python/ProjenrcOptions.java <==
package io.github.cdklabs.projen.python;

/**
 * (experimental) Options for <code>Projenrc</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.571Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.ProjenrcOptions")
@software.amazon.jsii.Jsii.Proxy(ProjenrcOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ProjenrcOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The name of the projenrc file.
     * <p>
     * Default: ".projenrc.py"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getFilename() {
        return null;
    }

    /**
     * (experimental) The projen version to use.
     * <p>
     * Default: - current version
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getProjenVersion() {
        return null;
    }

    /**
     * (experimental) Path to the python executable to use.
     * <p>
     * Default: "python"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getPythonExec() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<ProjenrcOptions> {
        java.lang.String filename;
        java.lang.String projenVersion;
        java.lang.String pythonExec;

        /**
         * Sets the value of {@link ProjenrcOptions#getFilename}
         * @param filename The name of the projenrc file.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder filename(java.lang.String filename) {
            this.filename = filename;
            return this;
        }

        /**
         * Sets the value of {@link ProjenrcOptions#getProjenVersion}
         * @param projenVersion The projen version to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder projenVersion(java.lang.String projenVersion) {
            this.projenVersion = projenVersion;
            return this;
        }

        /**
         * Sets the value of {@link ProjenrcOptions#getPythonExec}
         * @param pythonExec Path to the python executable to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pythonExec(java.lang.String pythonExec) {
            this.pythonExec = pythonExec;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ProjenrcOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public ProjenrcOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ProjenrcOptions {
        private final java.lang.String filename;
        private final java.lang.String projenVersion;
        private final java.lang.String pythonExec;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.filename = software.amazon.jsii.Kernel.get(this, "filename", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.projenVersion = software.amazon.jsii.Kernel.get(this, "projenVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.pythonExec = software.amazon.jsii.Kernel.get(this, "pythonExec", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.filename = builder.filename;
            this.projenVersion = builder.projenVersion;
            this.pythonExec = builder.pythonExec;
        }

        @Override
        public final java.lang.String getFilename() {
            return this.filename;
        }

        @Override
        public final java.lang.String getProjenVersion() {
            return this.projenVersion;
        }

        @Override
        public final java.lang.String getPythonExec() {
            return this.pythonExec;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getFilename() != null) {
                data.set("filename", om.valueToTree(this.getFilename()));
            }
            if (this.getProjenVersion() != null) {
                data.set("projenVersion", om.valueToTree(this.getProjenVersion()));
            }
            if (this.getPythonExec() != null) {
                data.set("pythonExec", om.valueToTree(this.getPythonExec()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.python.ProjenrcOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ProjenrcOptions.Jsii$Proxy that = (ProjenrcOptions.Jsii$Proxy) o;

            if (this.filename != null ? !this.filename.equals(that.filename) : that.filename != null) return false;
            if (this.projenVersion != null ? !this.projenVersion.equals(that.projenVersion) : that.projenVersion != null) return false;
            return this.pythonExec != null ? this.pythonExec.equals(that.pythonExec) : that.pythonExec == null;
        }

        @Override
        public final int hashCode() {
            int result = this.filename != null ? this.filename.hashCode() : 0;
            result = 31 * result + (this.projenVersion != null ? this.projenVersion.hashCode() : 0);
            result = 31 * result + (this.pythonExec != null ? this.pythonExec.hashCode() : 0);
            return result;
        }
    }
}
